@@ -683,12 +683,14 @@ void program_info(GtkWidget *emitter, gint info_code)
 {
      GtkWidget *popup, *label, *ok, *aboutlabel;
      GtkWidget *table, *vscroll;
+     GtkStyle *text_style;
      char labelname[512];
      char filename[512];
      char *pinfo = "Displaying Program Information:  ";
      char error_message[512];
      FILE *fp;                  /* Pointer to information file */
      char buffer[BUFFER_SIZE];
+     int max_width = -1, temp_width = 0;
 
      sprintf(labelname,"Program information:  ");
 
@@ -735,8 +737,6 @@ void program_info(GtkWidget *emitter, gint info_code)
      gtk_table_attach(GTK_TABLE(table), vscroll, 1, 2, 0, 1, 
                       GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
 
-     gtk_widget_set_usize(aboutlabel, 460, 505);
-
      /* Pack the label, then the table (with the text) into the dialog */
      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(popup)->vbox),
 			label, TRUE, TRUE, 0);
@@ -765,18 +765,36 @@ void program_info(GtkWidget *emitter, gint info_code)
      } /* End if */
      else
      {
+          text_style = gtk_widget_get_style(aboutlabel);
+          
 	  while(!feof(fp))
 	  {
 	       fgets(buffer,BUFFER_SIZE,fp);
-	       if(!feof(fp))
+               
+	       if(buffer) 
+               {
+                    temp_width = 
+                         gdk_string_width(text_style->font, buffer);
+                    
+                    if(temp_width > max_width) 
+                         max_width = temp_width;
+                    
 		    gtk_text_insert(GTK_TEXT(aboutlabel), NULL, NULL, NULL,
-				    buffer,strlen(buffer));
+				    buffer, strlen(buffer));
+               } /* End if */
 	  } /* End while */
 	  
 	  /* Close filestream */
 	  fclose(fp);
      } /* End else */
 
+     /* Set the width of the window to max_width which is the width of the
+      * widest line string in the file.  This should make it display like
+      * reasonable text regardless of what the person's systems default font
+      * is.  
+      */
+     gtk_widget_set_usize(aboutlabel, (max_width + 10), 300);
+
      gtk_text_thaw(GTK_TEXT(aboutlabel));
 
      gtk_window_set_position(GTK_WINDOW(popup), GTK_WIN_POS_CENTER);
