@@ -119,10 +119,6 @@ void enable_tooltips(void)
  */
 void status_report(GtkWidget *widget, gpointer data)
 {
-     /* Basically just strcat a bunch of crap together and throw it up
-      * to the screen.
-      */
-     
      char temp[2048];
      char on[]="ON ", 
 	  off[]="OFF ";
@@ -147,9 +143,9 @@ void status_report(GtkWidget *widget, gpointer data)
 
      strcat(temp,"\nNUM LOCK is ");
      if(options.NUMLOCK)
-	  strcat(temp,on);
+	  strcat(temp, on);
      else
-	  strcat(temp,off);
+	  strcat(temp, off);
 
      strcat(temp,"\nOur workingfile is ");
      if(!options.workingfile)
@@ -707,6 +703,7 @@ void gtkeyboard_mem_cleanup(void)
      MEMMSG("extrafiles.");            CONDFREE(options.extrafiles);
      MEMMSG("Redirect_window_name.");  CONDFREE(options.redirect_window_name);
      MEMMSG("keyboard_file.");         CONDFREE(options.keyboard_file);
+     MEMMSG("cache file.");            CONDFREE(options.cache_file);
 
      for(x=0; x<SHORTCUTS; x++)
      {
@@ -766,7 +763,7 @@ void gtkeyboard_mem_cleanup(void)
      CONDSMACK("GUI.toolbar_gtktb", GUI.toolbar_gtktb);
      CONDSMACK("GUI.main_output_text", GUI.main_output_text);
      CONDSMACK("GUI.master_text", GUI.master_text);
-     
+
      CONDSMACK("GUI.keyboard_elements.cursor_keys", 
                GUI.keyboard_elements.cursor_keys);
      CONDSMACK("GUI.keyboard_elements.keyboard", 
@@ -1111,7 +1108,7 @@ void forget_layout_settings(GtkWidget *emitter, gpointer data)
                                   " successfully deleted.  Layout settings ",
                                   "have been forgotten.\n");
           } /* End else */
-
+          
           g_free_(filename);
           return;
      } /* End else if */
