@@ -30,7 +30,7 @@
 #include "xpm/insert_completion.h"
 #include "libwcomp/config.h"
 
-#define CACHE_FILENAME_ERROR                            "none"
+#define CACHE_FILENAME_ERROR                     "none"
 
 static GtkWidget *completer_window = NULL;
 static GtkWidget *inputlabel = NULL;
@@ -47,7 +47,6 @@ static int EAVESDROP = 1;
 /* static prototypes */
 static gint insert_remainder         (GtkWidget *emitter, GdkEvent *event, 
                                       gpointer data);
-// (GtkWidget *emitter, gpointer data);
 static void empty_accumulator        (void);
 static void update_slots             (GtkWidget *emitter, gpointer data);
 static void find_cache_file          (GtkWidget *emitter, gpointer data);
@@ -331,7 +330,9 @@ int cacheify_file(char *from, char *to, int all_lowercase)
      cachefilename = get_valid_cache_filename();
      if(cachefilename && strcmp(cachefilename, CACHE_FILENAME_ERROR) == 0)
           return(0);
-
+     
+     fprintf(Q,"Cachefying-open.\n");
+     fflush(Q);
      comp = wcomp_open(cachefilename);
      
      if(cachefilename)
@@ -460,8 +461,15 @@ void completer_eavesdrop_on_letter(KeySym sym)
           return;
      } /* End if */
 
+     /* If we're not supposed to eavesdrop, then don't. */
      if(!EAVESDROP)
+     {
+#ifdef DEBUGGING
+          fprintf(Q,"Skipping KeySym on do not eavesdrop.\n");
+          fflush(Q);
+#endif /* DEBUGGING */
           return;
+     } /* End if */
 
      if(!isalnum(letter) &&
         !ISBLANK(letter) && 
@@ -565,15 +573,17 @@ void completer_eavesdrop_on_letter(KeySym sym)
                GTK_TOGGLE_BUTTON(show_unused_slots)))
           {
                gtk_widget_hide_all(completion_slot[x]);
-          } 
+          } /* End if */
           else gtk_widget_show_all(completion_slot[x]);
           x++;
      } /* End while */
 
+     /* Reset the label at the top of the completion window */
      sprintf(buffer,"Current Text: %s",
              ((accumulator[0] == '\0') ? 
               "None" : 
               accumulator));
+
      gtk_label_set_text(GTK_LABEL(inputlabel), buffer);
      gtk_widget_show(inputlabel);
 } /* End completer_eavesdrop_on_letter() */
@@ -750,6 +760,13 @@ void completer_window_new(void)
 
      if(completer_window || (slot[0] && GTK_IS_WIDGET(slot[0])) )
      {
+          /* If we don't do this, we'll run into some exceedingly nasty
+           * problems with one window's data walking all over the data
+           * of another window.  That sucks, so let's refuse to do it.
+           * If anybody can think of why a user could possibly need more
+           * than one completer window, let me know and I'll think about
+           * changing this policy
+           */
           gtkeyboard_error(1, "One completer window is already running.");
           return;
      } /* End if */
@@ -763,9 +780,7 @@ void completer_window_new(void)
       */
 
      completer_window = gtk_dialog_new();
-
      vbox = gtk_vbox_new(FALSE, 0);
-
      gtk_widget_realize(completer_window);
 
      for(x=0; x<MAX_COMPLETION_SLOTS; x++)
@@ -782,7 +797,8 @@ void completer_window_new(void)
           else gtk_container_add(GTK_CONTAINER(slot[x]),
                                  pixmap);
           
-          slotlabel[x] = gtk_label_new(" ");
+          /* The current term in this slot.  (Nothing initially) */
+          slotlabel[x]            = gtk_label_new(" ");
           completion_slot[x]      = gtk_hbox_new(FALSE, 0);
           
           sprintf(buf,"#%d:  ",(x+1));
@@ -862,14 +878,32 @@ void completer_window_new(void)
      /* Actually open the new file thingy.  default_file will be NULL if
       * the default filename exists 
       */
+     
      default_file = get_valid_cache_filename();
      if(default_file && strcmp(default_file, CACHE_FILENAME_ERROR) == 0)
      {
           gtk_widget_destroy(completer_window);
           return;
      } /* End if */
-
+     
+     fprintf(Q,"Opening default cache file: \"%s\"\n",
+             default_file ? default_file : "NULL");
+     fflush(Q);
      completer = wcomp_open(default_file);
+     
+     /* Whoops...the completer wasn't able to be created for one reason or
+      * another
+      */
+     if(!completer) {
+          gtkeyboard_error(6, "There was an error opening a valid cache file ",
+                           "for use with the completion mechanism.  Please ",
+                           "make sure that the system dictionary is in place ",
+                           "in either /usr/dict/words, /usr/share/dict/words,",
+                           " or specify a default cache file through the ",
+                           "GTKeyboard configuration file.");
+          gtk_widget_destroy(completer_window);
+          return;
+     } /* End if */
 
      if(default_file)
      {
@@ -879,17 +913,23 @@ void completer_window_new(void)
      wcomp_set_topnsize(completer, 10);
 
      /* ~/.gtkeyboard-wordcache */
-     sprintf(cache_filename, "%s%s%s",
-             options.home, _DIR, COMPLETER_CACHE_FILENAME);
+     if(options.cache_file)
+          strcpy(cache_filename, options.cache_file);
+     else
+          sprintf(cache_filename, "%s%s%s",
+                  options.home, _DIR, COMPLETER_CACHE_FILENAME);
 
      /* Try to read a cache file */
-     cache = fopen(cache_filename, "r");
+     if(options.cache_file)
+          cache = fopen(options.cache_file, "r");
+     else
+          cache = fopen(cache_filename, "r");
 
      if(!cache)
      {
           gtkeyboard_message(5,"Warning:  Could not open ",
                              cache_filename, ": ", g_strerror(errno), "\n");
-     } 
+     } /* End if */
      else
      {
           wcomp_read_cache(completer, cache);
